@@ -35,30 +35,11 @@ namespace hip {
 
 // Fat Binary Info
 class FatBinaryInfo {
-public:
+ public:
   FatBinaryInfo(const char* fname, const void* image);
   ~FatBinaryInfo();
 
-  // Loads Fat binary from file or image, unbundles COs for devices.
-  hipError_t ExtractFatBinaryUsingCOMGR(const std::vector<hip::Device*>& devices,
-      bool &containGenericTarget);
-
-  /**
-     *  @brief Extract code object from fatbin using comgr unbundling action via calling
-     *         CodeObject::extractCodeObjectFromFatBinaryUsingComgr
-     *
-     *  @param[in]  data the bundle data(fatbin or loaded module data). It can be in uncompressed,
-     *              compressed and even SPIR-V(to be supported later) mode.
-     *  @param[in]  devices devices whose code objects will be extracted.
-     *  Returned error code
-     *
-     *  @return #hipSuccess, #hipErrorNoBinaryForGpu, #hipErrorInvalidValue
-     *
-     *  @see CodeObject::extractCodeObjectFromFatBinaryUsingComgr()
-     */
-  hipError_t ExtractFatBinaryUsingCOMGR(const void* data,
-                                              const std::vector<hip::Device*>& devices);
-  hipError_t ExtractFatBinary(const std::vector<hip::Device*>& devices);
+  hipError_t ExtractFatBinaryUsingCOMGR(const std::vector<hip::Device*>& devices);
   hipError_t AddDevProgram(hip::Device* device, const void* binary_image, size_t binary_size,
                            size_t binary_offset);
   hipError_t BuildProgram(const int device_id);
@@ -90,25 +71,25 @@ public:
   //! Returns the lock for this fatbinary access
   amd::Monitor& FatBinaryLock() { return fb_lock_; }
 
-private:
-  std::string fname_;        //!< File name
-  amd::Os::FileDesc fdesc_;  //!< File descriptor
-  size_t fsize_;             //!< Total file size
-  size_t foffset_;           //!< File Offset where the fat binary is present.
+ private:
+  void ReleaseImageAndFile();
+
+  std::string fname_;  //!< File name
+  size_t foffset_;     //!< File Offset where the fat binary is present.
 
   // Even when file is passed image will be mmapped till ~desctructor.
-  const void* image_;        //!< Image
-  bool image_mapped_;        //!< flag to detect if image is mapped
+  const void* image_;  //!< Image
+  bool image_mapped_;  //!< flag to detect if image is mapped
 
   // Only used for FBs where image is directly passed
-  std::string uri_;          //!< Uniform resource indicator
+  std::string uri_;  //!< Uniform resource indicator
 
   std::vector<amd::Program*> dev_programs_;  //!< Program info per Device
 
-  std::shared_ptr<UniqueFD> ufd_; //!< Unique file descriptor
-  amd::Monitor fb_lock_{true};    //!< Lock for the fat binary access
+  std::shared_ptr<UniqueFD> ufd_;  //!< Unique file descriptor
+  amd::Monitor fb_lock_{true};     //!< Lock for the fat binary access
 };
 
-}; // namespace hip
+};  // namespace hip
 
-#endif // HIP_FAT_BINARY_HPP
+#endif  // HIP_FAT_BINARY_HPP
