@@ -19,7 +19,6 @@
  THE SOFTWARE. */
 
 #include <hip/hip_runtime.h>
-#include <elf/elf.hpp>
 #include <fstream>
 
 #include "hip_internal.hpp"
@@ -41,8 +40,6 @@ const std::string& FunctionName(const hipFunction_t f) {
   return hip::DeviceFunc::asFunction(f)->kernel()->name();
 }
 
-static uint64_t ElfSize(const void* emi) { return amd::Elf::getElfSize(emi); }
-
 hipError_t hipModuleUnload(hipModule_t hmod) {
   HIP_INIT_API(hipModuleUnload, hmod);
   if (hmod == nullptr) {
@@ -51,6 +48,11 @@ hipError_t hipModuleUnload(hipModule_t hmod) {
   CHECK_STREAM_CAPTURE_SUPPORTED();
   HIP_RETURN(PlatformState::instance().unloadModule(hmod));
 }
+hipError_t hipModuleLoadFatBinary(hipModule_t* module, const void* fatbin) {
+  HIP_INIT_API(hipModuleLoadFatBinary, module, fatbin);
+  HIP_RETURN(PlatformState::instance().loadModule(module, 0, fatbin));
+  HIP_RETURN(hipSuccess);
+}
 
 hipError_t hipModuleLoad(hipModule_t* module, const char* fname) {
   HIP_INIT_API(hipModuleLoad, module, fname);
@@ -92,6 +94,15 @@ hipError_t hipModuleGetFunction(hipFunction_t* hfunc, hipModule_t hmod, const ch
   HIP_RETURN(hipSuccess);
 }
 
+hipError_t hipModuleGetFunctionCount(unsigned int* count, hipModule_t mod) {
+  HIP_INIT_API(hipModuleGetFunctionCount, count, mod);
+
+  if (mod == nullptr) {
+    HIP_RETURN(hipErrorInvalidResourceHandle);
+  }
+  HIP_RETURN(PlatformState::instance().getFuncCount(count, mod););
+}
+
 hipError_t hipModuleGetGlobal(hipDeviceptr_t* dptr, size_t* bytes, hipModule_t hmod,
                               const char* name) {
   HIP_INIT_API(hipModuleGetGlobal, dptr, bytes, hmod, name);
@@ -183,7 +194,7 @@ hipError_t hipFuncGetAttributes(hipFuncAttributes* attr, const void* func) {
 hipError_t hipFuncSetAttribute(const void* func, hipFuncAttribute attr, int value) {
   HIP_INIT_API(hipFuncSetAttribute, func, attr, value);
 
-  if (func == nullptr)  {
+  if (func == nullptr) {
     HIP_RETURN(hipErrorInvalidDeviceFunction);
   }
   if (attr < 0 || attr > hipFuncAttributeMax) {
@@ -210,8 +221,7 @@ hipError_t hipFuncSetAttribute(const void* func, hipFuncAttribute attr, int valu
     HIP_RETURN(hipErrorInvalidDeviceFunction);
   }
   device::Kernel* d_kernel =
-                 (device::Kernel*)(kernel->getDeviceKernel(
-                  *(hip::getCurrentDevice()->devices()[0])));
+      (device::Kernel*)(kernel->getDeviceKernel(*(hip::getCurrentDevice()->devices()[0])));
 
   if (attr == hipFuncAttributeMaxDynamicSharedMemorySize) {
     if ((value < 0) || (value > (d_kernel->workGroupInfo()->availableLDSSize_ -
@@ -222,7 +232,7 @@ hipError_t hipFuncSetAttribute(const void* func, hipFuncAttribute attr, int valu
   }
 
   if (attr == hipFuncAttributePreferredSharedMemoryCarveout) {
-    if (value < -1 || value > 100)  {
+    if (value < -1 || value > 100) {
       HIP_RETURN(hipErrorInvalidValue);
     }
   }
@@ -233,7 +243,9 @@ hipError_t hipFuncSetAttribute(const void* func, hipFuncAttribute attr, int valu
 hipError_t hipFuncSetCacheConfig(const void* func, hipFuncCache_t cacheConfig) {
   HIP_INIT_API(hipFuncSetCacheConfig, cacheConfig);
 
-  if (func == nullptr) { HIP_RETURN(hipErrorInvalidDeviceFunction); }
+  if (func == nullptr) {
+    HIP_RETURN(hipErrorInvalidDeviceFunction);
+  }
   if (cacheConfig != hipFuncCachePreferNone && cacheConfig != hipFuncCachePreferShared &&
       cacheConfig != hipFuncCachePreferL1 && cacheConfig != hipFuncCachePreferEqual) {
     HIP_RETURN(hipErrorInvalidValue);
@@ -246,7 +258,9 @@ hipError_t hipFuncSetCacheConfig(const void* func, hipFuncCache_t cacheConfig) {
 hipError_t hipFuncSetSharedMemConfig(const void* func, hipSharedMemConfig config) {
   HIP_INIT_API(hipFuncSetSharedMemConfig, func, config);
 
-  if (func == nullptr) { HIP_RETURN(hipErrorInvalidDeviceFunction); }
+  if (func == nullptr) {
+    HIP_RETURN(hipErrorInvalidDeviceFunction);
+  }
   if (config != hipSharedMemBankSizeDefault && config != hipSharedMemBankSizeFourByte &&
       config != hipSharedMemBankSizeEightByte) {
     HIP_RETURN(hipErrorInvalidValue);
@@ -270,19 +284,19 @@ hipError_t ihipLaunchKernel_validate(hipFunction_t f, const amd::LaunchParams& l
     return hipErrorInvalidValue;
   }
 
-  if (launch_params.global_[0] == 0 || launch_params.global_[1] == 0
-                                     || launch_params.global_[2] == 0) {
+  if (launch_params.global_[0] == 0 || launch_params.global_[1] == 0 ||
+      launch_params.global_[2] == 0) {
     return hipErrorInvalidConfiguration;
   }
 
-  if (launch_params.local_[0] == 0 || launch_params.local_[1] == 0
-                                    || launch_params.local_[2] == 0) {
+  if (launch_params.local_[0] == 0 || launch_params.local_[1] == 0 ||
+      launch_params.local_[2] == 0) {
     return hipErrorInvalidConfiguration;
   }
 
   const amd::Device* device = g_devices[deviceId]->devices()[0];
   const auto& info = device->info();
-  if (launch_params.sharedMemBytes_ > info.localMemSizePerCU_) { //sharedMemPerBlock
+  if (launch_params.sharedMemBytes_ > info.localMemSizePerCU_) {  // sharedMemPerBlock
     return hipErrorInvalidValue;
   }
   // Make sure dispatch doesn't exceed max workgroup size limit
@@ -293,7 +307,7 @@ hipError_t ihipLaunchKernel_validate(hipFunction_t f, const amd::LaunchParams& l
   amd::Kernel* kernel = function->kernel();
   const amd::KernelSignature& signature = kernel->signature();
   if ((signature.numParameters() > 0) && (kernelParams == nullptr) && (extra == nullptr)) {
-    LogPrintfError("%s","At least one of kernelParams or extra Params should be provided");
+    LogPrintfError("%s", "At least one of kernelParams or extra Params should be provided");
     return hipErrorInvalidValue;
   }
   if (!kernel->getDeviceKernel(*device)) {
@@ -357,9 +371,9 @@ hipError_t ihipLaunchKernelCommand(amd::Command*& command, hipFunction_t f,
     params |= amd::NDRangeKernelCommand::AnyOrderLaunch;
   }
 
-  amd::NDRangeKernelCommand* kernelCommand = new amd::NDRangeKernelCommand(*stream, waitList,
-    *kernel, ndrange, launch_params.sharedMemBytes_, params, gridId, numGrids, prevGridSum,
-    allGridSum, firstDevice, profileNDRange);
+  amd::NDRangeKernelCommand* kernelCommand = new amd::NDRangeKernelCommand(
+      *stream, waitList, *kernel, ndrange, launch_params.sharedMemBytes_, params, gridId, numGrids,
+      prevGridSum, allGridSum, firstDevice, profileNDRange);
   if (!kernelCommand) {
     return hipErrorOutOfMemory;
   }
@@ -374,6 +388,7 @@ hipError_t ihipLaunchKernelCommand(amd::Command*& command, hipFunction_t f,
     assert(kernelParams == nullptr);
     if (extra[0] != HIP_LAUNCH_PARAM_BUFFER_POINTER || extra[2] != HIP_LAUNCH_PARAM_BUFFER_SIZE ||
         extra[4] != HIP_LAUNCH_PARAM_END) {
+      kernelCommand->release();
       return hipErrorInvalidValue;
     }
     kernargs = reinterpret_cast<address>(extra[1]);
@@ -391,8 +406,8 @@ hipError_t ihipLaunchKernelCommand(amd::Command*& command, hipFunction_t f,
   }
 
   if (DEBUG_HIP_KERNARG_COPY_OPT) {
-    if (CL_SUCCESS != kernelCommand->AllocCaptureSetValidate(kernelParams, kernargs,
-                                                             kernargs_size)) {
+    if (CL_SUCCESS !=
+        kernelCommand->AllocCaptureSetValidate(kernelParams, kernargs, kernargs_size)) {
       kernelCommand->release();
       return hipErrorOutOfMemory;
     }
@@ -432,6 +447,13 @@ hipError_t ihipModuleLaunchKernel(hipFunction_t f, amd::LaunchParams& launch_par
                                   uint64_t prevGridSum = 0, uint64_t allGridSum = 0,
                                   uint32_t firstDevice = 0) {
   int deviceId = hip::Stream::DeviceId(hStream);
+
+  // Ensure the stream's device matches the current device,
+  // or the grid's assigned device in CooperativeKernelMultiDevice mode
+  int targetDevice = (numGrids == 0) ? ihipGetDevice() : gridId;
+  if (deviceId != targetDevice) {
+    return hipErrorInvalidResourceHandle;
+  }
   HIP_RETURN_ONFAIL(PlatformState::instance().initStatManagedVarDevicePtr(deviceId));
 
   if (f == nullptr) {
@@ -440,10 +462,10 @@ hipError_t ihipModuleLaunchKernel(hipFunction_t f, amd::LaunchParams& launch_par
   }
   hip::DeviceFunc* function = hip::DeviceFunc::asFunction(f);
   amd::Kernel* kernel = function->kernel();
-  amd::ScopedLock lock (DEBUG_HIP_KERNARG_COPY_OPT ? nullptr : &function->dflock_);
+  amd::ScopedLock lock(DEBUG_HIP_KERNARG_COPY_OPT ? nullptr : &function->dflock_);
 
-  hipError_t status = ihipLaunchKernel_validate(f, launch_params, kernelParams, extra, deviceId,
-                                                params);
+  hipError_t status =
+      ihipLaunchKernel_validate(f, launch_params, kernelParams, extra, deviceId, params);
   if (status != hipSuccess) {
     return status;
   }
@@ -535,7 +557,7 @@ hipError_t hipModuleLaunchKernel(hipFunction_t f, uint32_t gridDimX, uint32_t gr
   amd::HIPLaunchParams launch_params(gridDimX, gridDimY, gridDimZ, blockDimX, blockDimY, blockDimZ,
                                      sharedMemBytes);
   if (!launch_params.IsValidConfig() ||
-       launch_params.local_.product() > device->info().maxWorkGroupSize_) {
+      launch_params.local_.product() > device->info().maxWorkGroupSize_) {
     HIP_RETURN(hipErrorInvalidValue);
   }
 
@@ -543,18 +565,18 @@ hipError_t hipModuleLaunchKernel(hipFunction_t f, uint32_t gridDimX, uint32_t gr
     HIP_RETURN(hipErrorInvalidValue);
   }
 
-  if (launch_params.global_[0] == 0 || launch_params.global_[1] == 0
-      || launch_params.global_[2] == 0) {
+  if (launch_params.global_[0] == 0 || launch_params.global_[1] == 0 ||
+      launch_params.global_[2] == 0) {
     HIP_RETURN(hipErrorInvalidValue);
   }
 
-  if (launch_params.local_[0] == 0 || launch_params.local_[1] == 0
-                                    || launch_params.local_[2] == 0) {
+  if (launch_params.local_[0] == 0 || launch_params.local_[1] == 0 ||
+      launch_params.local_[2] == 0) {
     HIP_RETURN(hipErrorInvalidValue);
   }
 
-  HIP_RETURN(ihipModuleLaunchKernel(f, launch_params, hStream, kernelParams, extra, nullptr,
-                                    nullptr));
+  HIP_RETURN(
+      ihipModuleLaunchKernel(f, launch_params, hStream, kernelParams, extra, nullptr, nullptr));
 }
 
 hipError_t hipExtModuleLaunchKernel(hipFunction_t f, uint32_t globalWorkSizeX,
@@ -575,9 +597,8 @@ hipError_t hipExtModuleLaunchKernel(hipFunction_t f, uint32_t globalWorkSizeX,
                  globalWorkSizeZ, localWorkSizeX, localWorkSizeY, localWorkSizeZ, sharedMemBytes,
                  kernelParams, extra, startEvent, stopEvent, flags);
 
-  amd::LaunchParams launch_params(globalWorkSizeX, globalWorkSizeY, globalWorkSizeZ,
-                                  localWorkSizeX, localWorkSizeY, localWorkSizeZ,
-                                  sharedMemBytes);
+  amd::LaunchParams launch_params(globalWorkSizeX, globalWorkSizeY, globalWorkSizeZ, localWorkSizeX,
+                                  localWorkSizeY, localWorkSizeZ, sharedMemBytes);
 
   HIP_RETURN(ihipModuleLaunchKernel(f, launch_params, hStream, kernelParams, extra, startEvent,
                                     stopEvent, flags));
@@ -622,7 +643,7 @@ hipError_t hipModuleLaunchCooperativeKernel(hipFunction_t f, unsigned int gridDi
                                      sharedMemBytes);
 
   if (!launch_params.IsValidConfig() ||
-       launch_params.local_.product() > device->info().maxWorkGroupSize_) {
+      launch_params.local_.product() > device->info().maxWorkGroupSize_) {
     HIP_RETURN(hipErrorInvalidValue);
   }
 
@@ -630,13 +651,13 @@ hipError_t hipModuleLaunchCooperativeKernel(hipFunction_t f, unsigned int gridDi
     HIP_RETURN(hipErrorInvalidValue);
   }
 
-  if (launch_params.global_[0] == 0 || launch_params.global_[1] == 0
-      || launch_params.global_[2] == 0) {
+  if (launch_params.global_[0] == 0 || launch_params.global_[1] == 0 ||
+      launch_params.global_[2] == 0) {
     HIP_RETURN(hipErrorInvalidValue);
   }
 
-  if (launch_params.local_[0] == 0 || launch_params.local_[1] == 0
-                                    || launch_params.local_[2] == 0) {
+  if (launch_params.local_[0] == 0 || launch_params.local_[1] == 0 ||
+      launch_params.local_[2] == 0) {
     HIP_RETURN(hipErrorInvalidValue);
   }
 
@@ -645,9 +666,8 @@ hipError_t hipModuleLaunchCooperativeKernel(hipFunction_t f, unsigned int gridDi
 }
 
 hipError_t ihipModuleLaunchCooperativeKernelMultiDevice(hipFunctionLaunchParams* launchParamsList,
-                                                       unsigned int  numDevices,
-                                                       unsigned int  flags,
-                                                       uint32_t extFlags) {
+                                                        unsigned int numDevices, unsigned int flags,
+                                                        uint32_t extFlags) {
   int numActiveGPUs = 0;
   hipError_t result = hipSuccess;
   result = ihipDeviceGetCount(&numActiveGPUs);
@@ -656,8 +676,8 @@ hipError_t ihipModuleLaunchCooperativeKernelMultiDevice(hipFunctionLaunchParams*
     return hipErrorInvalidValue;
   }
 
-  if (flags > (hipCooperativeLaunchMultiDeviceNoPostSync +
-               hipCooperativeLaunchMultiDeviceNoPreSync)) {
+  if (flags >
+      (hipCooperativeLaunchMultiDeviceNoPostSync + hipCooperativeLaunchMultiDeviceNoPreSync)) {
     return hipErrorInvalidValue;
   }
 
@@ -694,8 +714,7 @@ hipError_t ihipModuleLaunchCooperativeKernelMultiDevice(hipFunctionLaunchParams*
   // Sync the execution streams on all devices
   if ((flags & hipCooperativeLaunchMultiDeviceNoPreSync) == 0) {
     for (int i = 0; i < numDevices; ++i) {
-      hip::Stream* hip_stream =
-          reinterpret_cast<hip::Stream*>(launchParamsList[i].hStream);
+      hip::Stream* hip_stream = reinterpret_cast<hip::Stream*>(launchParamsList[i].hStream);
       hip_stream->finish();
     }
   }
@@ -740,10 +759,9 @@ hipError_t ihipModuleLaunchCooperativeKernelMultiDevice(hipFunctionLaunchParams*
       return hipErrorInvalidConfiguration;
     }
 
-    result = ihipModuleLaunchKernel(
-        launch.function, launch_params, launch.hStream, launch.kernelParams,
-        nullptr, nullptr, nullptr, flags, extFlags,
-        i, numDevices, prevGridSize, allGridSize, firstDevice);
+    result = ihipModuleLaunchKernel(launch.function, launch_params, launch.hStream,
+                                    launch.kernelParams, nullptr, nullptr, nullptr, flags, extFlags,
+                                    i, numDevices, prevGridSize, allGridSize, firstDevice);
     if (result != hipSuccess) {
       break;
     }
@@ -753,8 +771,7 @@ hipError_t ihipModuleLaunchCooperativeKernelMultiDevice(hipFunctionLaunchParams*
   // Sync the execution streams on all devices
   if ((flags & hipCooperativeLaunchMultiDeviceNoPostSync) == 0) {
     for (int i = 0; i < numDevices; ++i) {
-      hip::Stream* hip_stream =
-          reinterpret_cast<hip::Stream*>(launchParamsList[i].hStream);
+      hip::Stream* hip_stream = reinterpret_cast<hip::Stream*>(launchParamsList[i].hStream);
       hip_stream->finish();
     }
   }
@@ -763,8 +780,8 @@ hipError_t ihipModuleLaunchCooperativeKernelMultiDevice(hipFunctionLaunchParams*
 }
 
 hipError_t hipModuleLaunchCooperativeKernelMultiDevice(hipFunctionLaunchParams* launchParamsList,
-                                                       unsigned int  numDevices,
-                                                       unsigned int  flags) {
+                                                       unsigned int numDevices,
+                                                       unsigned int flags) {
   HIP_INIT_API(hipModuleLaunchCooperativeKernelMultiDevice, launchParamsList, numDevices, flags);
 
   if (launchParamsList == nullptr) {
@@ -779,19 +796,16 @@ hipError_t hipModuleLaunchCooperativeKernelMultiDevice(hipFunctionLaunchParams*
   }
 
   HIP_RETURN(ihipModuleLaunchCooperativeKernelMultiDevice(
-      launchParamsList,
-      numDevices,
-      flags,
+      launchParamsList, numDevices, flags,
       (amd::NDRangeKernelCommand::CooperativeGroups |
-      amd::NDRangeKernelCommand::CooperativeMultiDeviceGroups)));
-
+       amd::NDRangeKernelCommand::CooperativeMultiDeviceGroups)));
 }
 
 hipError_t hipGetFuncBySymbol(hipFunction_t* functionPtr, const void* symbolPtr) {
   HIP_INIT_API(hipGetFuncBySymbol, functionPtr, symbolPtr);
 
-  hipError_t hip_error = PlatformState::instance().getStatFunc(functionPtr,
-                         symbolPtr, ihipGetDevice());
+  hipError_t hip_error =
+      PlatformState::instance().getStatFunc(functionPtr, symbolPtr, ihipGetDevice());
 
   if ((hip_error != hipSuccess) || (functionPtr == nullptr)) {
     HIP_RETURN(hipErrorInvalidDeviceFunction);
@@ -800,31 +814,31 @@ hipError_t hipGetFuncBySymbol(hipFunction_t* functionPtr, const void* symbolPtr)
 }
 
 hipError_t hipLaunchKernel_common(const void* hostFunction, dim3 gridDim, dim3 blockDim,
-                                             void** args, size_t sharedMemBytes,
-                                             hipStream_t stream) {
+                                  void** args, size_t sharedMemBytes, hipStream_t stream) {
   STREAM_CAPTURE(hipLaunchKernel, stream, hostFunction, gridDim, blockDim, args, sharedMemBytes);
   return ihipLaunchKernel(hostFunction, gridDim, blockDim, args, sharedMemBytes, stream, nullptr,
                           nullptr, 0);
 }
 
-hipError_t hipLaunchKernel(const void* hostFunction, dim3 gridDim, dim3 blockDim,
-                                      void** args, size_t sharedMemBytes, hipStream_t stream) {
+hipError_t hipLaunchKernel(const void* hostFunction, dim3 gridDim, dim3 blockDim, void** args,
+                           size_t sharedMemBytes, hipStream_t stream) {
   HIP_INIT_API(hipLaunchKernel, hostFunction, gridDim, blockDim, args, sharedMemBytes, stream);
-  HIP_RETURN_DURATION(hipLaunchKernel_common(hostFunction, gridDim, blockDim, args, sharedMemBytes, stream));
+  HIP_RETURN_DURATION(
+      hipLaunchKernel_common(hostFunction, gridDim, blockDim, args, sharedMemBytes, stream));
 }
 
-hipError_t hipLaunchKernel_spt(const void* hostFunction, dim3 gridDim, dim3 blockDim,
-                                          void** args, size_t sharedMemBytes, hipStream_t stream) {
+hipError_t hipLaunchKernel_spt(const void* hostFunction, dim3 gridDim, dim3 blockDim, void** args,
+                               size_t sharedMemBytes, hipStream_t stream) {
   HIP_INIT_API(hipLaunchKernel, hostFunction, gridDim, blockDim, args, sharedMemBytes, stream);
   PER_THREAD_DEFAULT_STREAM(stream);
   HIP_RETURN(hipLaunchKernel_common(hostFunction, gridDim, blockDim, args, sharedMemBytes, stream));
 }
 
-hipError_t hipExtLaunchKernel(const void* hostFunction, dim3 gridDim, dim3 blockDim,
-                                         void** args, size_t sharedMemBytes, hipStream_t stream,
-                                         hipEvent_t startEvent, hipEvent_t stopEvent, int flags) {
-  HIP_INIT_API(hipExtLaunchKernel, hostFunction, gridDim, blockDim, args, sharedMemBytes,
-               stream, startEvent, stopEvent, flags);
+hipError_t hipExtLaunchKernel(const void* hostFunction, dim3 gridDim, dim3 blockDim, void** args,
+                              size_t sharedMemBytes, hipStream_t stream, hipEvent_t startEvent,
+                              hipEvent_t stopEvent, int flags) {
+  HIP_INIT_API(hipExtLaunchKernel, hostFunction, gridDim, blockDim, args, sharedMemBytes, stream,
+               startEvent, stopEvent, flags);
 
   if (!hip::isValid(startEvent) || !hip::isValid(stopEvent)) {
     HIP_RETURN(hipErrorInvalidValue);
@@ -870,13 +884,13 @@ hipError_t hipLaunchCooperativeKernel_common(const void* f, dim3 gridDim, dim3 b
     return hipErrorCooperativeLaunchTooLarge;
   }
 
-  if (launch_params.global_[0] == 0 || launch_params.global_[1] == 0
-      || launch_params.global_[2] == 0) {
+  if (launch_params.global_[0] == 0 || launch_params.global_[1] == 0 ||
+      launch_params.global_[2] == 0) {
     return hipErrorInvalidConfiguration;
   }
 
-  return ihipModuleLaunchKernel(func, launch_params, hStream, kernelParams, nullptr,
-                                nullptr, nullptr, 0, amd::NDRangeKernelCommand::CooperativeGroups);
+  return ihipModuleLaunchKernel(func, launch_params, hStream, kernelParams, nullptr, nullptr,
+                                nullptr, 0, amd::NDRangeKernelCommand::CooperativeGroups);
 }
 
 hipError_t hipLaunchCooperativeKernel(const void* f, dim3 gridDim, dim3 blockDim,
@@ -898,9 +912,12 @@ hipError_t hipLaunchCooperativeKernel_spt(const void* f, dim3 gridDim, dim3 bloc
 
 hipError_t ihipLaunchCooperativeKernelMultiDevice(hipLaunchParams* launchParamsList, int numDevices,
                                                   unsigned int flags, uint32_t extFlags) {
-  if (launchParamsList == nullptr || numDevices > g_devices.size()) {
+  if (launchParamsList == nullptr) {
     return hipErrorInvalidValue;
   }
+  if (numDevices > g_devices.size()) {
+    return hipErrorInvalidDevice;
+  }
 
   std::vector<hipFunctionLaunchParams> functionLaunchParamsList(numDevices);
   // Convert hipLaunchParams to hipFunctionLaunchParams
@@ -956,10 +973,8 @@ hipError_t ihipLaunchCooperativeKernelMultiDevice(hipLaunchParams* launchParamsL
     functionLaunchParamsList[i].kernelParams = launch.args;
   }
 
-  return ihipModuleLaunchCooperativeKernelMultiDevice(functionLaunchParamsList.data(),
-                                                      functionLaunchParamsList.size(),
-                                                      flags,
-                                                      extFlags);
+  return ihipModuleLaunchCooperativeKernelMultiDevice(
+      functionLaunchParamsList.data(), functionLaunchParamsList.size(), flags, extFlags);
 }
 
 hipError_t hipLaunchCooperativeKernelMultiDevice(hipLaunchParams* launchParamsList, int numDevices,
@@ -1020,8 +1035,8 @@ hipError_t hipModuleGetTexRef(textureReference** texRef, hipModule_t hmod, const
 hipError_t hipLinkAddData(hipLinkState_t hip_link_state, hipJitInputType input_type, void* image,
                           size_t image_size, const char* name, unsigned int num_options,
                           hipJitOption* options_ptr, void** option_values) {
-
-  HIP_INIT_API(hipLinkAddData, hip_link_state, image, image_size, name, num_options, options_ptr, option_values);
+  HIP_INIT_API(hipLinkAddData, hip_link_state, image, image_size, name, num_options, options_ptr,
+               option_values);
 
   if (image == nullptr || image_size <= 0) {
     HIP_RETURN(hipErrorInvalidImage);
@@ -1029,9 +1044,9 @@ hipError_t hipLinkAddData(hipLinkState_t hip_link_state, hipJitInputType input_t
 
   if (input_type == hipJitInputCubin || input_type == hipJitInputPtx ||
       input_type == hipJitInputFatBinary || input_type == hipJitInputObject ||
-      input_type ==  hipJitInputLibrary || input_type == hipJitInputNvvm ||
+      input_type == hipJitInputLibrary || input_type == hipJitInputNvvm ||
       input_type == hipJitInputLLVMBitcode || input_type == hipJitInputLLVMBundledBitcode ||
-      input_type == hipJitInputLLVMArchivesOfBundledBitcode ) {
+      input_type == hipJitInputLLVMArchivesOfBundledBitcode) {
     HIP_RETURN(hipErrorInvalidValue);
   }
 
@@ -1040,8 +1055,7 @@ hipError_t hipLinkAddData(hipLinkState_t hip_link_state, hipJitInputType input_t
     input_name = name;
   }
 
-  LinkProgram* hip_link_prog_ptr =
-      reinterpret_cast<LinkProgram*>(hip_link_state);
+  LinkProgram* hip_link_prog_ptr = reinterpret_cast<LinkProgram*>(hip_link_state);
 
   if (!LinkProgram::isLinkerValid(hip_link_prog_ptr)) {
     HIP_RETURN(hipErrorInvalidHandle);
@@ -1054,9 +1068,11 @@ hipError_t hipLinkAddData(hipLinkState_t hip_link_state, hipJitInputType input_t
   HIP_RETURN(hipSuccess);
 }
 
-hipError_t hipLinkAddFile(hipLinkState_t hip_link_state, hipJitInputType input_type, const char* file_path,
-                          unsigned int num_options, hipJitOption* options_ptr, void** option_values) {
-  HIP_INIT_API(hipLinkAddFile, hip_link_state, input_type, file_path, num_options, options_ptr, option_values);
+hipError_t hipLinkAddFile(hipLinkState_t hip_link_state, hipJitInputType input_type,
+                          const char* file_path, unsigned int num_options,
+                          hipJitOption* options_ptr, void** option_values) {
+  HIP_INIT_API(hipLinkAddFile, hip_link_state, input_type, file_path, num_options, options_ptr,
+               option_values);
 
   if (hip_link_state == nullptr) {
     HIP_RETURN(hipErrorInvalidHandle);
@@ -1064,14 +1080,13 @@ hipError_t hipLinkAddFile(hipLinkState_t hip_link_state, hipJitInputType input_t
 
   if (input_type == hipJitInputCubin || input_type == hipJitInputPtx ||
       input_type == hipJitInputFatBinary || input_type == hipJitInputObject ||
-      input_type ==  hipJitInputLibrary || input_type == hipJitInputNvvm ||
+      input_type == hipJitInputLibrary || input_type == hipJitInputNvvm ||
       input_type == hipJitInputLLVMBitcode || input_type == hipJitInputLLVMBundledBitcode ||
-      input_type == hipJitInputLLVMArchivesOfBundledBitcode ) {
+      input_type == hipJitInputLLVMArchivesOfBundledBitcode) {
     HIP_RETURN(hipErrorInvalidValue);
   }
 
-  LinkProgram* hip_link_prog_ptr =
-      reinterpret_cast<LinkProgram*>(hip_link_state);
+  LinkProgram* hip_link_prog_ptr = reinterpret_cast<LinkProgram*>(hip_link_state);
 
   if (!LinkProgram::isLinkerValid(hip_link_prog_ptr)) {
     HIP_RETURN(hipErrorInvalidValue);
@@ -1085,7 +1100,7 @@ hipError_t hipLinkAddFile(hipLinkState_t hip_link_state, hipJitInputType input_t
 }
 
 hipError_t hipLinkCreate(unsigned int num_options, hipJitOption* options_ptr,
-                              void** options_vals_pptr, hipLinkState_t* hip_link_state_ptr) {
+                         void** options_vals_pptr, hipLinkState_t* hip_link_state_ptr) {
   HIP_INIT_API(hipLinkCreate, num_options, options_ptr, options_vals_pptr, hip_link_state_ptr);
 
   if (hip_link_state_ptr == nullptr) {
@@ -1093,9 +1108,47 @@ hipError_t hipLinkCreate(unsigned int num_options, hipJitOption* options_ptr,
   }
 
   if (num_options != 0) {
-    for (int i = 0; i < num_options; i++) {
-      if (options_ptr == nullptr || options_vals_pptr == nullptr) {
-        HIP_RETURN(hipErrorInvalidValue);
+    if (options_ptr == nullptr || options_vals_pptr == nullptr) {
+      HIP_RETURN(hipErrorInvalidValue);
+    }
+
+    for (int i = 0; i < num_options; ++i) {
+      switch (options_ptr[i]) {
+        // CUDA only options
+        case hipJitOptionMaxRegisters:
+        case hipJitOptionThreadsPerBlock:
+        case hipJitOptionWallTime:
+        case hipJitOptionInfoLogBuffer:
+        case hipJitOptionInfoLogBufferSizeBytes:
+        case hipJitOptionErrorLogBuffer:
+        case hipJitOptionErrorLogBufferSizeBytes:
+        case hipJitOptionOptimizationLevel:
+        case hipJitOptionTargetFromContext:
+        case hipJitOptionTarget:
+        case hipJitOptionFallbackStrategy:
+        case hipJitOptionGenerateDebugInfo:
+        case hipJitOptionLogVerbose:
+        case hipJitOptionGenerateLineInfo:
+        case hipJitOptionCacheMode:
+        case hipJitOptionSm3xOpt:
+        case hipJitOptionFastCompile:
+        case hipJitOptionGlobalSymbolNames:
+        case hipJitOptionGlobalSymbolAddresses:
+        case hipJitOptionGlobalSymbolCount:
+        case hipJitOptionLto:
+        case hipJitOptionFtz:
+        case hipJitOptionPrecDiv:
+        case hipJitOptionPrecSqrt:
+        case hipJitOptionFma:
+        case hipJitOptionPositionIndependentCode:
+        case hipJitOptionMinCTAPerSM:
+        case hipJitOptionMaxThreadsPerBlock:
+        case hipJitOptionOverrideDirectiveValues:
+        case hipJitOptionNumOptions:
+          HIP_RETURN(hipErrorInvalidValue);
+        default:
+          // everything else is fine
+          break;
       }
     }
   }
@@ -1118,8 +1171,7 @@ hipError_t hipLinkComplete(hipLinkState_t hip_link_state, void** bin_out, size_t
     HIP_RETURN(hipErrorInvalidValue);
   }
 
-  LinkProgram* hip_link_prog_ptr =
-      reinterpret_cast<LinkProgram*>(hip_link_state);
+  LinkProgram* hip_link_prog_ptr = reinterpret_cast<LinkProgram*>(hip_link_state);
 
   if (!LinkProgram::isLinkerValid(hip_link_prog_ptr)) {
     HIP_RETURN(hipErrorInvalidValue);
@@ -1135,8 +1187,7 @@ hipError_t hipLinkComplete(hipLinkState_t hip_link_state, void** bin_out, size_t
 hipError_t hipLinkDestroy(hipLinkState_t hip_link_state) {
   HIP_INIT_API(hipLinkDestroy, hip_link_state);
 
-  LinkProgram* hip_link_prog_ptr =
-      reinterpret_cast<LinkProgram*>(hip_link_state);
+  LinkProgram* hip_link_prog_ptr = reinterpret_cast<LinkProgram*>(hip_link_state);
 
   if (!LinkProgram::isLinkerValid(hip_link_prog_ptr)) {
     HIP_RETURN(hipErrorInvalidValue);
@@ -1158,7 +1209,7 @@ hipError_t hipLaunchKernelExC(const hipLaunchConfig_t* config, const void* fPtr,
 
   if (config->numAttrs == 0) {
     HIP_RETURN_DURATION(hipLaunchKernel_common(fPtr, config->gridDim, config->blockDim, args,
-      config->dynamicSmemBytes, config->stream));
+                                               config->dynamicSmemBytes, config->stream));
   }
 
   for (size_t attr_idx = 0; attr_idx < config->numAttrs; ++attr_idx) {
@@ -1206,8 +1257,7 @@ hipError_t hipDrvLaunchKernelEx(const HIP_LAUNCH_CONFIG* config, hipFunction_t f
   for (size_t attr_idx = 0; attr_idx < config->numAttrs; ++attr_idx) {
     hipLaunchAttribute& attr = config->attrs[attr_idx];
     switch (attr.id) {
-      case hipLaunchAttributeCooperative:
-      {
+      case hipLaunchAttributeCooperative: {
         if (attr.value.cooperative != 0) {
           HIP_RETURN(ihipModuleLaunchKernel(f, launch_params, config->hStream, kernelParams,
                                             nullptr, nullptr, nullptr, 0,
