@@ -34,7 +34,7 @@ hipError_t ihipOccupancyMaxActiveBlocksPerMultiprocessor(
 // Unique file descriptor class
 struct UniqueFD {
   UniqueFD(const std::string& fpath, amd::Os::FileDesc fdesc, size_t fsize)
-           : fpath_(fpath), fdesc_(fdesc), fsize_(fsize) {}
+      : fpath_(fpath), fdesc_(fdesc), fsize_(fsize) {}
 
   const std::string fpath_;        //!< File path of this unique file
   const amd::Os::FileDesc fdesc_;  //!< File Descriptor
@@ -43,10 +43,12 @@ struct UniqueFD {
 
 namespace hip {
 class PlatformState {
-  amd::Monitor lock_{"Guards PlatformState globals", true};
+  // Guards PlatformState globals
+  amd::Monitor lock_{true};
 
   // global level lock for unique file descritor map: ufd_map_
-  amd::Monitor ufd_lock_{"Unique FD Store Lock", true};
+  // Unique FD Store Lock
+  amd::Monitor ufd_lock_{true};
 
   // Singleton object
   static PlatformState* platform_;
@@ -59,8 +61,9 @@ class PlatformState {
   // Dynamic Code Objects functions
   hipError_t loadModule(hipModule_t* module, const char* fname, const void* image = nullptr);
   hipError_t unloadModule(hipModule_t hmod);
-
+  bool isValidDynFunc(const void* hfunc);
   hipError_t getDynFunc(hipFunction_t* hfunc, hipModule_t hmod, const char* func_name);
+  hipError_t getFuncCount(unsigned int* count, hipModule_t hmod);
   hipError_t getDynGlobalVar(const char* hostVar, hipModule_t hmod, hipDeviceptr_t* dev_ptr,
                              size_t* size_ptr);
   hipError_t getDynTexRef(const char* hostVar, hipModule_t hmod, textureReference** texRef);
@@ -80,7 +83,7 @@ class PlatformState {
   }
 
   // Static Code Objects functions
-  hip::FatBinaryInfo** addFatBinary(const void* data);
+  hip::FatBinaryInfo** addFatBinary(const void* data, bool& success);
   hipError_t removeFatBinary(hip::FatBinaryInfo** module);
   hipError_t digestFatBinary(const void* data, hip::FatBinaryInfo*& programs);
 
@@ -110,6 +113,23 @@ class PlatformState {
 
   size_t UfdMapSize() const { return ufd_map_.size(); }
 
+  inline bool RegisterLibraryFunction(const hipKernel_t f) {
+    amd::ScopedLock lock(lock_);
+    if (library_functions_.find(f) == library_functions_.end()) {
+      library_functions_.insert(f);
+      return true;
+    }
+    return false;
+  }
+  inline bool UnregisterLibraryFunction(const hipKernel_t f) {
+    amd::ScopedLock lock(lock_);
+    if (library_functions_.find(f) != library_functions_.end()) {
+      library_functions_.erase(f);
+      return true;
+    }
+    return false;
+  }
+
  private:
   // Dynamic Code Object map, keyin module to get the corresponding object
   std::unordered_map<hipModule_t, hip::DynCO*> dynCO_map_;
@@ -117,8 +137,9 @@ class PlatformState {
   bool initialized_{false};
   std::unordered_map<textureReference*, std::pair<hipModule_t, std::string>> texRef_map_;
 
-  std::unordered_map<std::string, std::shared_ptr<UniqueFD>> ufd_map_; //!< Unique File Desc Map
+  std::unordered_map<std::string, std::shared_ptr<UniqueFD>> ufd_map_;  //!< Unique File Desc Map
 
   void* dynamicLibraryHandle_{nullptr};
+  std::unordered_set<hipKernel_t> library_functions_;
 };
 }  // namespace hip
