@@ -29,8 +29,7 @@ class OCLCreatePipe : public OCLTestImp {
   virtual ~OCLCreatePipe();
 
  public:
-  virtual void open(unsigned int test, char* units, double& conversion,
-                    unsigned int deviceID);
+  virtual void open(unsigned int test, char* units, double& conversion, unsigned int deviceID);
   virtual void run(void);
 };
 
