@@ -25,62 +25,62 @@
 namespace amd::pal {
 
 static constexpr std::array<PCIndexSelect, 50> blockIdToIndexSelect = {{
-    PCIndexSelect::None,                     // CPF
-    PCIndexSelect::ShaderEngine,             // IA
-    PCIndexSelect::ShaderEngine,             // VGT
-    PCIndexSelect::ShaderArray,              // PA
-    PCIndexSelect::ShaderArray,              // SC
-    PCIndexSelect::ShaderEngine,             // SPI
-    PCIndexSelect::ShaderEngine,             // SQ
-    PCIndexSelect::ShaderArray,              // SX
-    PCIndexSelect::ComputeUnit,              // TA
-    PCIndexSelect::ComputeUnit,              // TD
-    PCIndexSelect::ComputeUnit,              // TCP
-    PCIndexSelect::Instance,                 // TCC
-    PCIndexSelect::Instance,                 // TCA
-    PCIndexSelect::ShaderArray,              // DB
-    PCIndexSelect::ShaderArray,              // CB
-    PCIndexSelect::None,                     // GDS
-    PCIndexSelect::None,                     // SRBM
-    PCIndexSelect::None,                     // GRBM
-    PCIndexSelect::ShaderEngine,             // GRBMSE
-    PCIndexSelect::None,                     // RLC
-    PCIndexSelect::Instance,                 // DMA
-    PCIndexSelect::None,                     // MC
-    PCIndexSelect::None,                     // CPG
-    PCIndexSelect::None,                     // CPC
-    PCIndexSelect::None,                     // WD
-    PCIndexSelect::None,                     // TCS
-    PCIndexSelect::None,                     // ATC
-    PCIndexSelect::None,                     // ATCL2
-    PCIndexSelect::None,                     // MCVML2
-    PCIndexSelect::Instance,                 // EA
-    PCIndexSelect::None,                     // RPB
-    PCIndexSelect::ShaderArray,              // RMI
-    PCIndexSelect::Instance,                 // UMCCH
-    PCIndexSelect::Instance,                 // GE
-    PCIndexSelect::ShaderArray,              // GL1A
-    PCIndexSelect::ShaderArray,              // GL1C
-    PCIndexSelect::ShaderArray,              // GL1CG
-    PCIndexSelect::Instance,                 // GL2A
-    PCIndexSelect::Instance,                 // GL2C
-    PCIndexSelect::None,                     // CHA
-    PCIndexSelect::Instance,                 // CHC
-    PCIndexSelect::None,                     // CHCG
-    PCIndexSelect::None,                     // GUS
-    PCIndexSelect::None,                     // GCR
-    PCIndexSelect::None,                     // PH
-    PCIndexSelect::ShaderArray,              // UTCL1
-    PCIndexSelect::None,                     // GeDist
-    PCIndexSelect::ShaderEngine,             // GeSe
-    PCIndexSelect::None,                     // Df
-    PCIndexSelect::ComputeUnit,              // SqWgp
+    PCIndexSelect::None,          // CPF
+    PCIndexSelect::ShaderEngine,  // IA
+    PCIndexSelect::ShaderEngine,  // VGT
+    PCIndexSelect::ShaderArray,   // PA
+    PCIndexSelect::ShaderArray,   // SC
+    PCIndexSelect::ShaderEngine,  // SPI
+    PCIndexSelect::ShaderEngine,  // SQ
+    PCIndexSelect::ShaderArray,   // SX
+    PCIndexSelect::ComputeUnit,   // TA
+    PCIndexSelect::ComputeUnit,   // TD
+    PCIndexSelect::ComputeUnit,   // TCP
+    PCIndexSelect::Instance,      // TCC
+    PCIndexSelect::Instance,      // TCA
+    PCIndexSelect::ShaderArray,   // DB
+    PCIndexSelect::ShaderArray,   // CB
+    PCIndexSelect::None,          // GDS
+    PCIndexSelect::None,          // SRBM
+    PCIndexSelect::None,          // GRBM
+    PCIndexSelect::ShaderEngine,  // GRBMSE
+    PCIndexSelect::None,          // RLC
+    PCIndexSelect::Instance,      // DMA
+    PCIndexSelect::None,          // MC
+    PCIndexSelect::None,          // CPG
+    PCIndexSelect::None,          // CPC
+    PCIndexSelect::None,          // WD
+    PCIndexSelect::None,          // TCS
+    PCIndexSelect::None,          // ATC
+    PCIndexSelect::None,          // ATCL2
+    PCIndexSelect::None,          // MCVML2
+    PCIndexSelect::Instance,      // EA
+    PCIndexSelect::None,          // RPB
+    PCIndexSelect::ShaderArray,   // RMI
+    PCIndexSelect::Instance,      // UMCCH
+    PCIndexSelect::Instance,      // GE
+    PCIndexSelect::ShaderArray,   // GL1A
+    PCIndexSelect::ShaderArray,   // GL1C
+    PCIndexSelect::ShaderArray,   // GL1CG
+    PCIndexSelect::Instance,      // GL2A
+    PCIndexSelect::Instance,      // GL2C
+    PCIndexSelect::None,          // CHA
+    PCIndexSelect::Instance,      // CHC
+    PCIndexSelect::None,          // CHCG
+    PCIndexSelect::None,          // GUS
+    PCIndexSelect::None,          // GCR
+    PCIndexSelect::None,          // PH
+    PCIndexSelect::ShaderArray,   // UTCL1
+    PCIndexSelect::None,          // GeDist
+    PCIndexSelect::ShaderEngine,  // GeSe
+    PCIndexSelect::None,          // Df
+    PCIndexSelect::ComputeUnit,   // SqWgp
 }};
 
 PalCounterReference* PalCounterReference::Create(VirtualGPU& gpu) {
   Pal::Result result;
 
-  if (blockIdToIndexSelect.size() !=  static_cast<size_t>(Pal::GpuBlock::Count)) {
+  if (blockIdToIndexSelect.size() != static_cast<size_t>(Pal::GpuBlock::Count)) {
     LogError("Size of blockIdToIndexSelect does not match GpuBlock::Count");
   }
 
@@ -194,7 +194,7 @@ bool PalCounterReference::finalize() {
 
     assert(layout.sampleCount == numExpCounters_);
     size_t size = sizeof(Pal::GlobalCounterLayout) +
-        (sizeof(Pal::GlobalSampleLayout) * (layout.sampleCount - 1));
+                  (sizeof(Pal::GlobalSampleLayout) * (layout.sampleCount - 1));
     layout_ = reinterpret_cast<Pal::GlobalCounterLayout*>(new char[size]);
     if (layout_ != nullptr) {
       layout_->sampleCount = layout.sampleCount;
@@ -722,15 +722,16 @@ bool PerfCounter::create() {
       break;
 
     case PCIndexSelect::ShaderArray:
-      if (info_.counterIndex_ >=
-          (dev().properties().gfxipProperties.shaderCore.numShaderArrays * dev().properties().gfxipProperties.shaderCore.numShaderEngines)) {
+      if (info_.counterIndex_ >= (dev().properties().gfxipProperties.shaderCore.numShaderArrays *
+                                  dev().properties().gfxipProperties.shaderCore.numShaderEngines)) {
         return true;
       }
       counter_start = info_.counterIndex_;
-      counter_step = dev().properties().gfxipProperties.shaderCore.numShaderArrays * dev().properties().gfxipProperties.shaderCore.numShaderEngines;
+      counter_step = dev().properties().gfxipProperties.shaderCore.numShaderArrays *
+                     dev().properties().gfxipProperties.shaderCore.numShaderEngines;
       break;
 
-      case PCIndexSelect::ComputeUnit:
+    case PCIndexSelect::ComputeUnit:
       if (info_.counterIndex_ >=
           dev().properties().gfxipProperties.shaderCore.maxCusPerShaderArray) {
         return true;
