@@ -59,21 +59,18 @@ UberTraceCaptureMgr* UberTraceCaptureMgr::Create(Pal::IPlatform* platform, const
 
 // ================================================================================================
 UberTraceCaptureMgr::UberTraceCaptureMgr(Pal::IPlatform* platform, const Device& device)
-  : device_(device),
-    dev_driver_server_(platform->GetDevDriverServer()),
-    global_disp_count_(1), // Must start from 1 according to RGP spec
-    user_event_(nullptr),
-    current_event_id_(0),
-    trace_session_(platform->GetTraceSession()),
-    trace_controller_(nullptr),
-    code_object_trace_source_(nullptr),
-    queue_timings_trace_source_(nullptr) {
-}
+    : device_(device),
+      dev_driver_server_(platform->GetDevDriverServer()),
+      global_disp_count_(1),  // Must start from 1 according to RGP spec
+      user_event_(nullptr),
+      current_event_id_(0),
+      trace_session_(platform->GetTraceSession()),
+      trace_controller_(nullptr),
+      code_object_trace_source_(nullptr),
+      queue_timings_trace_source_(nullptr) {}
 
 // ================================================================================================
-UberTraceCaptureMgr::~UberTraceCaptureMgr() {
-  DestroyUberTraceResources();
-}
+UberTraceCaptureMgr::~UberTraceCaptureMgr() { DestroyUberTraceResources(); }
 
 // ================================================================================================
 bool UberTraceCaptureMgr::CreateUberTraceResources(Pal::IPlatform* platform) {
@@ -175,18 +172,17 @@ bool UberTraceCaptureMgr::Init(Pal::IPlatform* platform) {
 }
 
 // ================================================================================================
-void UberTraceCaptureMgr::PreDispatch(VirtualGPU* gpu, const HSAILKernel& kernel,
-                                      size_t x, size_t y, size_t z) {
+void UberTraceCaptureMgr::PreDispatch(VirtualGPU* gpu, const HSAILKernel& kernel, size_t x,
+                                      size_t y, size_t z) {
   // Wait for the driver to be resumed in case it's been paused.
   WaitForDriverResume();
 
   // Increment dispatch count in RenderOp trace controller
   Pal::IQueue* pQueue = gpu->queue(MainEngine).iQueue_;
-  GpuUtil::RenderOpCounts opCounts =
-  {
+  GpuUtil::RenderOpCounts opCounts = {
       .dispatchCount = 1u,
   };
-  trace_controller_->RecordRenderOps(pQueue,opCounts);
+  trace_controller_->RecordRenderOps(pQueue, opCounts);
 
   if (trace_session_->GetTraceSessionState() == GpuUtil::TraceSessionState::Running) {
     RgpSqttMarkerEventType apiEvent = RgpSqttMarkerEventType::CmdNDRangeKernel;
@@ -226,8 +222,7 @@ void UberTraceCaptureMgr::PreDispatch(VirtualGPU* gpu, const HSAILKernel& kernel
 }
 
 // ================================================================================================
-void UberTraceCaptureMgr::PostDispatch(VirtualGPU* gpu) {
-}
+void UberTraceCaptureMgr::PostDispatch(VirtualGPU* gpu) {}
 
 // ================================================================================================
 // Waits for the driver to be resumed if it's currently paused.
@@ -257,8 +252,7 @@ bool UberTraceCaptureMgr::IsQueueTimingActive() const {
 }
 
 // ================================================================================================
-bool UberTraceCaptureMgr::RegisterTimedQueue(uint32_t queue_id,
-                                             Pal::IQueue* iQueue,
+bool UberTraceCaptureMgr::RegisterTimedQueue(uint32_t queue_id, Pal::IQueue* iQueue,
                                              bool* debug_vmid) const {
   // Get the OS context handle for this queue (this is a thing that RGP needs on DX clients;
   // it may be optional for Vulkan, but we provide it anyway if available).
@@ -267,9 +261,8 @@ bool UberTraceCaptureMgr::RegisterTimedQueue(uint32_t queue_id,
 
   // QueryKernelContextInfo may fail.
   // If so, just use a context identifier of 0.
-  uint64_t queueContext = (result == Pal::Result::Success)
-                        ? kernelContextInfo.contextIdentifier
-                        : 0;
+  uint64_t queueContext =
+      (result == Pal::Result::Success) ? kernelContextInfo.contextIdentifier : 0;
 
   // Register the queue with the GPA session class for timed queue operation support.
   result = queue_timings_trace_source_->RegisterTimedQueue(iQueue, queue_id, queueContext);
@@ -291,9 +284,7 @@ Pal::Result UberTraceCaptureMgr::TimedQueueSubmit(Pal::IQueue* queue, uint64_t c
   timedSubmitInfo.frameIndex = 0;
 
   // Do a timed submit of all the command buffers
-  Pal::Result result = queue_timings_trace_source_->TimedSubmit(queue,
-                                                                submitInfo,
-                                                                timedSubmitInfo);
+  Pal::Result result = queue_timings_trace_source_->TimedSubmit(queue, submitInfo, timedSubmitInfo);
 
   // Punt to non-timed submit if a timed submit fails (or is not supported)
   if (result != Pal::Result::Success) {
@@ -315,8 +306,8 @@ uint64_t UberTraceCaptureMgr::AddElfBinary(const void* exe_binary, size_t exe_bi
                                            Pal::IGpuMemory* pGpuMemory, size_t offset) {
   GpuUtil::ElfBinaryInfo elfBinaryInfo = {};
   elfBinaryInfo.pBinary = exe_binary;
-  elfBinaryInfo.binarySize = exe_binary_size; ///< FAT Elf binary size.
-  elfBinaryInfo.pGpuMemory = pGpuMemory;      ///< GPU Memory where the compiled ISA resides.
+  elfBinaryInfo.binarySize = exe_binary_size;  ///< FAT Elf binary size.
+  elfBinaryInfo.pGpuMemory = pGpuMemory;       ///< GPU Memory where the compiled ISA resides.
   elfBinaryInfo.offset = static_cast<Pal::gpusize>(offset);
 
   elfBinaryInfo.originalHash = DevDriver::MetroHash::MetroHash64(
@@ -341,8 +332,10 @@ void UberTraceCaptureMgr::WriteMarker(const VirtualGPU* gpu, const void* data,
   Pal::RgpMarkerSubQueueFlags subQueueFlags = {};
   subQueueFlags.includeMainSubQueue = 1;
 
-  gpu->queue(MainEngine).iCmd()->CmdInsertRgpTraceMarker(
-    subQueueFlags, static_cast<uint32_t>(data_size / sizeof(uint32_t)), data);
+  gpu->queue(MainEngine)
+      .iCmd()
+      ->CmdInsertRgpTraceMarker(subQueueFlags, static_cast<uint32_t>(data_size / sizeof(uint32_t)),
+                                data);
 }
 
 // ================================================================================================
@@ -350,8 +343,8 @@ void UberTraceCaptureMgr::WriteMarker(const VirtualGPU* gpu, const void* data,
 void UberTraceCaptureMgr::WriteComputeBindMarker(const VirtualGPU* gpu, uint64_t api_hash) const {
   RgpSqttMarkerPipelineBind marker = {};
   marker.identifier = RgpSqttMarkerIdentifierBindPipeline;
-  marker.cbID       = gpu->queue(MainEngine).cmdBufId();
-  marker.bindPoint  = 1;
+  marker.cbID = gpu->queue(MainEngine).cmdBufId();
+  marker.bindPoint = 1;
 
   memcpy(marker.apiPsoHash, &api_hash, sizeof(api_hash));
   WriteMarker(gpu, &marker, sizeof(marker));
@@ -360,18 +353,18 @@ void UberTraceCaptureMgr::WriteComputeBindMarker(const VirtualGPU* gpu, uint64_t
 // ================================================================================================
 // Inserts an RGP pre-dispatch marker
 void UberTraceCaptureMgr::WriteEventWithDimsMarker(const VirtualGPU* gpu,
-                                                   RgpSqttMarkerEventType apiType,
-                                                   uint32_t x, uint32_t y, uint32_t z) const {
+                                                   RgpSqttMarkerEventType apiType, uint32_t x,
+                                                   uint32_t y, uint32_t z) const {
   assert(apiType != RgpSqttMarkerEventType::Invalid);
 
   RgpSqttMarkerEvent event = {};
   event.identifier = RgpSqttMarkerIdentifierEvent;
-  event.apiType    = static_cast<uint32_t>(apiType);
-  event.cmdID      = current_event_id_++;
-  event.cbID       = gpu->queue(MainEngine).cmdBufId();
+  event.apiType = static_cast<uint32_t>(apiType);
+  event.cmdID = current_event_id_++;
+  event.cbID = gpu->queue(MainEngine).cmdBufId();
 
   RgpSqttMarkerEventWithDims eventWithDims = {};
-  eventWithDims.event   = event;
+  eventWithDims.event = event;
   eventWithDims.event.hasThreadDims = 1;
   eventWithDims.threadX = x;
   eventWithDims.threadY = y;
@@ -387,10 +380,10 @@ void UberTraceCaptureMgr::WriteBarrierStartMarker(const VirtualGPU* gpu,
     amd::ScopedLock traceLock(&trace_mutex_);
 
     RgpSqttMarkerBarrierStart marker = {};
-    marker.cbId       = gpu->queue(MainEngine).cmdBufId();
+    marker.cbId = gpu->queue(MainEngine).cmdBufId();
     marker.identifier = RgpSqttMarkerIdentifierBarrierStart;
-    marker.internal   = true;
-    marker.dword02    = data.reason;
+    marker.internal = true;
+    marker.dword02 = data.reason;
 
     WriteMarker(gpu, &marker, sizeof(marker));
   }
@@ -407,30 +400,30 @@ void UberTraceCaptureMgr::WriteBarrierEndMarker(const VirtualGPU* gpu,
     // syncs and pipeline stalls.
     Pal::Developer::BarrierOperations operations = data.operations;
     operations.pipelineStalls.u16All |= 0;
-    operations.caches.u16All         |= 0;
+    operations.caches.u16All |= 0;
 
     RgpSqttMarkerBarrierEnd marker = {};
-    marker.identifier              = RgpSqttMarkerIdentifierBarrierEnd;
-    marker.cbId                    = gpu->queue(MainEngine).cmdBufId();
-    marker.numLayoutTransitions    = 0;
-    marker.waitOnEopTs             = operations.pipelineStalls.eopTsBottomOfPipe;
-    marker.vsPartialFlush          = operations.pipelineStalls.vsPartialFlush;
-    marker.psPartialFlush          = operations.pipelineStalls.psPartialFlush;
-    marker.csPartialFlush          = operations.pipelineStalls.csPartialFlush;
-    marker.pfpSyncMe               = operations.pipelineStalls.pfpSyncMe;
-    marker.syncCpDma               = operations.pipelineStalls.syncCpDma;
-    marker.invalTcp                = operations.caches.invalTcp;
-    marker.invalSqI                = operations.caches.invalSqI$;
-    marker.invalSqK                = operations.caches.invalSqK$;
-    marker.flushTcc                = operations.caches.flushTcc;
-    marker.invalTcc                = operations.caches.invalTcc;
-    marker.flushCb                 = operations.caches.flushCb;
-    marker.invalCb                 = operations.caches.invalCb;
-    marker.flushDb                 = operations.caches.flushDb;
-    marker.invalDb                 = operations.caches.invalDb;
+    marker.identifier = RgpSqttMarkerIdentifierBarrierEnd;
+    marker.cbId = gpu->queue(MainEngine).cmdBufId();
+    marker.numLayoutTransitions = 0;
+    marker.waitOnEopTs = operations.pipelineStalls.eopTsBottomOfPipe;
+    marker.vsPartialFlush = operations.pipelineStalls.vsPartialFlush;
+    marker.psPartialFlush = operations.pipelineStalls.psPartialFlush;
+    marker.csPartialFlush = operations.pipelineStalls.csPartialFlush;
+    marker.pfpSyncMe = operations.pipelineStalls.pfpSyncMe;
+    marker.syncCpDma = operations.pipelineStalls.syncCpDma;
+    marker.invalTcp = operations.caches.invalTcp;
+    marker.invalSqI = operations.caches.invalSqI$;
+    marker.invalSqK = operations.caches.invalSqK$;
+    marker.flushTcc = operations.caches.flushTcc;
+    marker.invalTcc = operations.caches.invalTcc;
+    marker.flushCb = operations.caches.flushCb;
+    marker.invalCb = operations.caches.invalCb;
+    marker.flushDb = operations.caches.flushDb;
+    marker.invalDb = operations.caches.invalDb;
 
     WriteMarker(gpu, &marker, sizeof(marker));
   }
 }
 
-} // namespace amd::pal
+}  // namespace amd::pal
